==> params-flow-0.1.9.tar.gz: params-flow-0.1.9/setup.py <==
#!/usr/bin/env python

#
# created by kpe on 08.04.2019 at 9:33 PM
#


from setuptools import setup


with open("README.rst", "r") as fh:
    long_description = fh.read()

with open("requirements.txt", "r") as reader:
    install_requires = list(map(lambda x: x.strip(), reader.readlines()))


setup(name='params-flow',
      version='0.1.9',
      description='Tensorflow Keras utilities for reducing boilerplate code.',
      url='https://github.com/kpe/params-flow/',
      author='kpe',
      author_email='kpe.git@gmailbox.org',
      license='MIT',
      keywords='tensorflow keras',
      packages=['params_flow'],
      package_data={'params_flow': ['tests/*.py', 'requirements.txt']},
      long_description=long_description,
      long_description_content_type="text/x-rst",
      zip_safe=False,
      include_package_data=True,
      install_requires=install_requires,
      python_requires=">=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*",
      classifiers=[
          "Development Status :: 5 - Production/Stable",
          "License :: OSI Approved :: MIT License",
          "Programming Language :: Python",
          "Programming Language :: Python :: 2",
          "Programming Language :: Python :: 2.7",
          "Programming Language :: Python :: 3",
          "Programming Language :: Python :: 3.4",
          "Programming Language :: Python :: 3.5",
          "Programming Language :: Python :: 3.6",
          "Programming Language :: Python :: 3.7",
          "Programming Language :: Python :: Implementation :: CPython",
          "Programming Language :: Python :: Implementation :: PyPy"])

==> params-flow-0.7.0.tar.gz: params-flow-0.7.0/setup.py <==
#!/usr/bin/env python

#
# created by kpe on 08.04.2019 at 9:33 PM
#


from setuptools import setup, find_packages, convert_path


def _version():
    ns = {}
    with open(convert_path("params_flow/version.py"), "r") as fh:
        exec(fh.read(), ns)
    return ns['__version__']


__version__ = _version()


with open("README.rst", "r") as fh:
    long_description = fh.read()

with open("requirements.txt", "r") as reader:
    install_requires = list(map(lambda x: x.strip(), reader.readlines()))


setup(name="params-flow",
      version=__version__,
      url="https://github.com/kpe/params-flow/",
      description="Tensorflow Keras utilities for reducing boilerplate code.",
      long_description=long_description,
      long_description_content_type="text/x-rst",
      keywords="tensorflow keras",
      license="MIT",
      author="kpe",
      author_email="kpe.git@gmailbox.org",

      packages=find_packages(exclude=["tests"]),

      include_package_data=True,
      zip_safe=False,

      install_requires=install_requires,
      python_requires=">=3.5",
      classifiers=[
          "Development Status :: 5 - Production/Stable",
          "License :: OSI Approved :: MIT License",
          "Programming Language :: Python",
          "Programming Language :: Python :: 3",
          "Programming Language :: Python :: 3.5",
          "Programming Language :: Python :: 3.6",
          "Programming Language :: Python :: 3.7",
          "Programming Language :: Python :: Implementation :: CPython",
          "Programming Language :: Python :: Implementation :: PyPy"])
